# frozen_string_literal: true
class SolrDocument
  include Blacklight::Solr::Document
  include Blacklight::Gallery::OpenseadragonSolrDocument

  # Adds Hyrax behaviors to the SolrDocument.
  include Hyrax::SolrDocumentBehavior


  # self.unique_key = 'id'

  # Email uses the semantic field mappings below to generate the body of an email.
  SolrDocument.use_extension(Blacklight::Document::Email)

  # SMS uses the semantic field mappings below to generate the body of an SMS email.
  SolrDocument.use_extension(Blacklight::Document::Sms)

  # DublinCore uses the semantic field mappings below to assemble an OAI-compliant Dublin Core document
  # Semantic mappings of solr stored fields. Fields may be multi or
  # single valued. See Blacklight::Document::SemanticFields#field_semantics
  # and Blacklight::Document::SemanticFields#to_semantic_values
  # Recommendation: Use field names from Dublin Core
  use_extension(Blacklight::Document::DublinCore)

  # Do content negotiation for AF models. 

  use_extension( Hydra::ContentNegotiation )

  def approval_number
    self[Solrizer.solr_name('approval_number', :symbol)]
  end

  def complex_date
    self[Solrizer.solr_name('complex_date', :displayable)]
  end

  def complex_funding_reference
    self[Solrizer.solr_name('complex_funding_reference', :displayable)]
  end

  def complex_identifier
    self[Solrizer.solr_name('complex_identifier', :displayable)]
  end

  def complex_person
    self[Solrizer.solr_name('complex_person', :displayable)]
  end

  def complex_relation
    self[Solrizer.solr_name('complex_relation', :displayable)]
  end

  def complex_subject
    self[Solrizer.solr_name('complex_subject', :displayable)]
  end

  def coverage
    self[Solrizer.solr_name('coverage', :stored_searchable)]
  end

  def crc_resource_type
    self[Solrizer.solr_name('crc_resource_type', :stored_searchable)]
  end

  def crc_work_type
    self[Solrizer.solr_name('crc_work_type', :stored_searchable)]
  end

  def for_complex_identifier
    self[Solrizer.solr_name('for_complex_identifier', :stored_searchable)]
  end

  def for_complex_type
    self[Solrizer.solr_name('for_complex_type', :stored_searchable)]
  end

  def dataset_method
    self[Solrizer.solr_name('dataset_method', :stored_searchable)]
  end

  def tombstone_status
    self[Solrizer.solr_name('tombstone_status', :symbol)]
  end

  def is_tombstoned
    self[Solrizer.solr_name('is_tombstoned', :symbol)]
  end

  def tombstone_date
    self[Solrizer.solr_name('tombstone_date', :symbol)]
  end

  def doi
    self[Solrizer.solr_name('doi', :symbol)]
  end

  def extra_information
    self[Solrizer.solr_name('extra_information', :stored_searchable)]
  end

  def experiment_description
    self[Solrizer.solr_name('experiment_description', :stored_searchable)]
  end

  def experiment_title
    self[Solrizer.solr_name('experiment_title', :stored_searchable)]
  end

  def modality
    self[Solrizer.solr_name('modality', :stored_searchable)]
  end

  def parent_work_id
    self[Solrizer.solr_name('parent_work_id', :symbol)]
  end

  def series_information
    self[Solrizer.solr_name('series_information', :stored_searchable)]
  end

  def software_version
    self[Solrizer.solr_name('software_version', :stored_searchable)]
  end

  def table_of_contents
    self[Solrizer.solr_name('table_of_contents', :stored_searchable)]
  end

  def technical_information
    self[Solrizer.solr_name('technical_information', :stored_searchable)]
  end

  def crc_collection_type
    self[Solrizer.solr_name('crc_collection_type', :stored_searchable)]
  end
end
