# frozen_string_literal: true
module Hyrax
  module Workflow
    ##
    # This is a built in function for workflow, so that a workflow action can be created that
    # grants the creator the ability to view their work.
    module GrantReadToGroupManager
      # @param [#read_users=, #read_users] target to which we are adding read_users
      #   for the depositor
      # @return void
      def self.call(target:, **)
        collection = target.parent_collections.first

        group_key = "#{collection.collection_type.title.parameterize(separator: '_')}_#{collection.id}_manager"

        target.update(read_groups: target.read_groups.to_a + [group_key])

        GrantReadToGroupJob.perform_later(target, group_key)
      end
    end
  end
end